@@ -14,10 +14,11 @@ struct Size {
   template <class T>
   static rfl::Result<T> validate(const T& _t) {
     const auto to_t = [&](const auto&) { return _t; };
-    const auto embellish_error = [](const auto& _err) {
+    const auto embellish_error = [](const auto& _err) -> Error {
       return Error("Size validation failed: " + _err.what());
     };
-    return V::validate(_t.size()).transform(to_t).or_else(embellish_error);
+    return V::validate(_t.size()).transform(to_t).transform_error(
+        embellish_error);
   }
 
   template <class T>
