@@ -3,7 +3,12 @@
 
 #include <istream>
 #include <string>
-#include <toml++/toml.hpp>
+#include <string_view>
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Warray-bounds"
+#include <toml.hpp>
+#pragma GCC diagnostic pop
 
 #include "../Processors.hpp"
 #include "../internal/wrap_in_rfl_array_t.hpp"
@@ -25,11 +30,22 @@ auto read(InputVarType _var) {
   return Parser<T, ProcessorsType>::read(r, _var);
 }
 
-/// Parses an object from TOML using reflection.
+/// Reads a TOML string.
 template <class T, class... Ps>
 Result<internal::wrap_in_rfl_array_t<T>> read(const std::string& _toml_str) {
-  auto table = ::toml::parse(_toml_str);
-  return read<T, Ps...>(&table);
+  auto res = ::toml::try_parse_str(_toml_str);
+  if (res.is_ok()) {
+    return read<T, Ps...>(&res.unwrap());
+  } else {
+    return error(::toml::format_error(res.unwrap_err().at(0)));
+  }
+}
+
+/// Reads a TOML string.
+template <class T, class... Ps>
+Result<internal::wrap_in_rfl_array_t<T>> read(
+    const std::string_view _toml_str) {
+  return read<T, Ps...>(std::string(_toml_str));
 }
 
 /// Parses an object from a stringstream.
